RxGo class

Inheritance

Constructors

RxGo({Key? key, required String url, Map<String, String>? headers = const {}, dynamic arguments, bool canClose = false, bool fullscreen = false, bool showControl = true, dynamic onRouteChange(Uri? uri)?, bool hideProtected = false, bool hideLink = false, bool cacheEnabled = false, String? body, bool? enableZoom, Color backgroundColor = Colors.white, WebViewCookieManager? cookieManager})
const

Properties

arguments → dynamic
final
backgroundColor → Color
final
body → String?
final
cacheEnabled → bool
final
canClose → bool
final
cookieManager → WebViewCookieManager?
final
enableZoom → bool?
final
fullscreen → bool
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
final
final
hideProtected → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onRouteChange → dynamic Function(Uri? uri)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showControl → bool
final
url → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<RxGo>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

no setter

Static Methods

close<T>(String name, [T? result]) → void
closeRoute<T>(Route route, [T? result]) → void
debug(String type, [dynamic message, dynamic info, dynamic moreInfo]) → void
log(String type, [dynamic message, dynamic info, dynamic moreInfo]) → void
open<T>(String url, {dynamic arguments, String? name, RxGoController<T>? controller, bool canClose = false, bool hideProtected = false, bool hideLink = false, bool fullscreen = false, bool showControl = true, Map<String, String>? headers, WebViewCookieManager? cookieManager, dynamic onRouteChange(Uri? uri)?, Color? backgroundColor, bool? enableZoom}) → RxGoController<T?>
openBottomSheet<T>(Widget bottomSheet, {dynamic arguments, String? name, RxGoController<T>? controller, bool canClose = false, bool fullscreen = false, bool showControl = true, dynamic onRouteChange(Uri? uri)?, Color? backgroundColor}) → RxGoController<T?>
openWithBody<T>(String body, {dynamic arguments, String? name, RxGoController<T>? controller, bool canClose = false, bool hideProtected = false, bool hideLink = false, bool fullscreen = false, bool showControl = true, Map<String, String>? headers, WebViewCookieManager? cookieManager, dynamic onRouteChange(Uri? uri)?, Color? backgroundColor, bool? enableZoom}) → RxGoController<T?>